@@ -1,10 +1,10 @@
-# RCS Status      : $Id: FontInfo.pm,v 1.2 1999-03-07 16:00:53+01 jv Exp $
+# RCS Status      : $Id: FontInfo.pm,v 1.12 2003-10-23 14:12:27+02 jv Exp $
 # Author          : Johan Vromans
-# Created On      : December 1999
+# Created On      : December 1998
 # Last Modified By: Johan Vromans
-# Last Modified On: Sun Mar  7 15:51:24 1999
-# Update Count    : 36
-# Status          : Looks okay
+# Last Modified On: Thu Oct 23 14:12:25 2003
+# Update Count    : 57
+# Status          : Released
 
 ################ Module Preamble ################
 
@@ -14,33 +14,38 @@ use strict;
 
 BEGIN { require 5.005; }
 
-use IO;
+use IO qw(File);
 
 use vars qw($VERSION);
-$VERSION = "1.0";
-
-my $trace;
-my $verbose;
+$VERSION = "1.05";
 
 sub new {
     my $class = shift;
     my $font = shift;
     my (%atts) = (error => 'die',
-		  verbose => 0, trace => 0,
+		  verbose => 0, trace => 0, debug => 0,
 		  @_);
     my $self = { file => $font };
     bless $self, $class;
 
-    $trace = lc($atts{trace});
-    $verbose = $trace || lc($atts{verbose});
+    return $self unless defined $font;
+
+    $self->{debug}   = $atts{debug};
+    $self->{trace}   = $self->{debug} || $atts{trace};
+    $self->{verbose} = $self->{trace} || $atts{verbose};
+
+    my $error = lc($atts{error});
+    $self->{die} = sub {
+	die(@_)     if $error eq "die";
+	warn(@_)    if $error eq "warn";
+    };
 
     eval {
 	$self->_loadinfo;
     };
 
     if ( $@ ) {
-	die ($@) unless lc($atts{error}) eq "warn";
-	warn ($@);
+	$self->_die($@);
 	return undef;
     }
 
@@ -49,6 +54,7 @@ sub new {
 
 sub FileName	{ my $self = shift; $self->{file};    }
 sub FontName	{ my $self = shift; $self->{name};    }
+sub FullName	{ my $self = shift; $self->{fullname};}
 sub InfoData	{ my $self = shift; $self->{data};    }
 sub FontFamily	{ my $self = shift; $self->{family};  }
 sub Version	{ my $self = shift; $self->{version}; }
@@ -66,8 +72,8 @@ sub _loadinfo ($) {
 	my $fh = new IO::File;	# font file
 	my $sz = -s $fn;	# file size
 
-	$fh->open ($fn) || die ("$fn: $!\n");
-	print STDERR ("$fn: Loading INF file\n") if $verbose;
+	$fh->open ($fn) || $self->_die("$fn: $!\n");
+	print STDERR ("$fn: Loading INF file\n") if $self->{verbose};
 
 	# Read in the inf data.
 	my $len = 0;
@@ -75,19 +81,20 @@ sub _loadinfo ($) {
 	    $len = length ($data);
 	}
 	$fh->close;
-	print STDERR ("Read $len bytes from $fn\n") if $trace;
-	die ("$fn: Expecting $sz bytes, got $len bytes\n") unless $sz == $len;
+	print STDERR ("Read $len bytes from $fn\n") if $self->{trace};
+	$self->_die("$fn: Expecting $sz bytes, got $len bytes\n") unless $sz == $len;
 
 	# Normalise line endings.
 	$data =~ s/\015\012?/\n/g;
 
 	if ( $data !~ /^FontName\s+\(\S+\)$/m ) {
-	    die ("$fn: Not a recognizable INF file\n");
+	    $self->_die("$fn: Not a recognizable INF file\n");
 	}
 
     };
 
     $self->{name}    = $1 if $data =~ /^FontName\s+\((\S+)\)$/mi;
+    $self->{fullname}= $1 if $data =~ /^FullName\s+\((.+?)\)$/mi;
     $self->{family}  = $1 if $data =~ /^FamilyName\s+\((.+)\)$/mi;
     $self->{version} = $1 if $data =~ /^Version\s+\((.+)\)$/mi;
     $self->{pcprefix}= lc($1)
@@ -97,6 +104,11 @@ sub _loadinfo ($) {
     $self;
 }
 
+sub _die {
+    my ($self, @msg) = @_;
+    $self->{die}->(@msg);
+}
+
 1;
 
 __END__
@@ -112,24 +124,6 @@ PostScript::FontInfo - module to fetch data from PostScript font C<.inf> files
   my $info = new PostScript::FontInfo (filename, options);
   print STDOUT ("Name = ", $info->name, "\n");
 
-=head1 OPTIONS
-
-=over 4
-
-=item error => [ 'die' | 'warn' ]
-
-How errors must be handled.
-
-=item verbose => I<value>
-
-Prints verbose info if I<value> is true.
-
-=item trace => I<value>
-
-Prints tracing info if I<value> is true.
-
-=back
-
 =head1 DESCRIPTION
 
 This package allows font info files, so called C<.inf> files, to be
@@ -139,12 +133,39 @@ read and (partly) parsed.
 
 =over 4
 
-=item new ( FILENAME )
+=item new ( FILENAME [ , OPTIONS ] )
 
 The constructor will read the file and parse its contents.
 
 =back
 
+=head1 OPTIONS
+
+=over 4
+
+=item error => [ 'die' | 'warn' | 'ignore' ]
+
+B<DEPRECATED>. Please use 'eval { ... }' to intercept errors.
+
+How errors must be handled. Default is to call die().
+In any case, new() returns a undefined result.
+Setting 'error' to 'ignore' may cause surprising results.
+
+=item verbose => I<value>
+
+Prints verbose info if I<value> is true.
+
+=item trace => I<value>
+
+Prints tracing info if I<value> is true.
+
+=item debug => I<value>
+
+Prints debugging info if I<value> is true.
+Implies 'trace' and 'verbose'.
+
+=back
+
 =head1 INSTANCE METHODS
 
 Each of these methods can return C<undef> if the corresponding
@@ -154,13 +175,17 @@ information could not be found in the file.
 
 =item FileName
 
-The name of the file, e.g. 'tir_____.afm'.
+The name of the file, e.g. 'tir_____.inf'.
 
 =item FontName
 
 The name of the font, e.g. 'Times-Roman'.
 
-=item FamilyName
+=item FullName
+
+The full name of the font, e.g. 'Times Roman'.
+
+=item FontFamily
 
 The family name of the font, e.g. 'Times'.
 
@@ -184,7 +209,7 @@ Johan Vromans, Squirrel Consultancy <jvromans@squirrel.nl>
 
 =head1 COPYRIGHT and DISCLAIMER
 
-This program is Copyright 1993,1999 by Squirrel Consultancy. All
+This program is Copyright 2003,1998 by Squirrel Consultancy. All
 rights reserved.
 
 This program is free software; you can redistribute it and/or modify
